@@ -57,6 +57,7 @@ class Employee(ModelSQL, ModelView, Cacheable):
             for edate, ecost in employee_costs:
                 if date >= edate:
                     cost = ecost
+                else:
                     break
         return cost
 
@@ -129,7 +130,7 @@ class EmployeeCostPrice(ModelSQL, ModelView):
         return res
 
     def on_change_with_currency_digits(self, vals):
-        company_obj = Pool().get('company.employee')
+        employee_obj = Pool().get('company.employee')
         if vals.get('employee'):
             employee = employee_obj.browse(vals['employee'])
             return employee.company.currency.digits
